Simple Module to check the packaging and upload to pypi
```
>snakey ishan
    _______
    (ishan)
    -------
             /
            /
       __  /
      {00}
      (__)\
       ?? \\
          _\\__
         (_____)_
         (______)Oo*
```